/* chnconv.h */
/* This header file is for CHNCONV.DLL */

/* by Harigaya Soichi */
/* updated at 3 Mar 2009 */

/* Please include <windows.h> before "chnconv.h" */

#ifndef CHNCONV_H
#define CHNCONV_H

#ifdef __cplusplus
extern "C" {
#endif


#include <stddef.h>

#if defined _MSC_VER && _MSC_VER < 1300 || defined __BORLANDC__ && __BORLANDC__ < 1370
#ifndef _INTPTR_T_DEFINED
#define _INTPTR_T_DEFINED
#ifdef _WIN64
  typedef __int64 intptr_t ;
#else
  typedef int intptr_t ;
#endif
#endif
#endif



typedef struct {
   size_t cbSize ;
   const char *pGbFont ;
   const char *pGbGothicFont ;
   const char *pBig5Font ;
   const char *pBig5GothicFont ;
   const char *pPinyinFont ;
   const char *pPinyinGothicFont ;
} CHNFONTINFO ;



typedef struct {
   int nSrc ;
   int nDst ;
} CHNCONV_USERDEF ;



typedef struct {

   size_t cbSize ;
   unsigned long dwConversionMode ;
   unsigned long dwAdditionalMode ;

// Writing RTF
   const CHNFONTINFO *pFontInfo ;

// User-Defined Conversion
   const CHNCONV_USERDEF *pSrcToDst ;
   size_t nNumberOfSrcToDst ;

   const CHNCONV_USERDEF *pSrcToUc ;
   size_t nNumberOfSrcToUc ;

// Reading TechnoMate
   int nFontSize ;

// Reserved
   void *pReserved ;

} CHNCONVEXINFO ;




/* Functions */
int WINAPI ChnconvExA ( const char *szSrcFileName, const char *szDstFileName, int nSrcCodePage, int nDstCodePage, const CHNCONVEXINFO *pInfo ) ;
int WINAPI ChnconvExW ( const wchar_t *szSrcFileName, const wchar_t *szDstFileName, int nSrcCodePage, int nDstCodePage, const CHNCONVEXINFO *pInfo ) ;
intptr_t WINAPI ChnconvStringEx ( const char *szSrcBuffer, char *szDstBuffer, int nSrcCodePage, int nDstCodePage, const CHNCONVEXINFO *pInfo, size_t nMaxLen ) ;
int WINAPI ChnconvCharEx ( int C, int nSrcCodePage, int nDstCodePage, const CHNCONVEXINFO *pInfo ) ;
int WINAPI IsChnconvValidCodePage ( int nSrcCodePage, int nDstCodePage ) ;
int WINAPI GetChnconvLastError ( void ) ;
int WINAPI AbortChnconv ( void ) ;
int WINAPI GetDllVersion ( void ) ;


#ifdef UNICODE
#define ChnconvEx ChnconvExW
#else
#define ChnconvEx ChnconvExA
#endif



/* for Backward Compatibility */
/* Obsolete Functions, not thread-safe */
int WINAPI ChnconvA ( const char *pSrcFileName, const char *pDstFileName, int nSrcCodePage, int nDstCodePage, unsigned long dwFlags ) ;
int WINAPI ChnconvW ( const wchar_t *pSrcFileName, const wchar_t *pDstFileName, int nSrcCodePage, int nDstCodePage, unsigned long dwFlags ) ;
intptr_t WINAPI ChnconvString ( const char *pSrcBuffer, char *pDstBuffer, int nSrcCodePage, int nDstCodePage, unsigned long dwFlags, size_t nMaxLen ) ;
int WINAPI ChnconvChar ( int C, int nSrcCodePage, int nDstCodePage, unsigned long dwFlags ) ;
int WINAPI SetGbFontName ( const char *pFontName, const char *pGothicFontName ) ;
int WINAPI SetBig5FontName ( const char *pFontName, const char *pGothicFontName ) ;
int WINAPI SetPinyinFontName ( const char *pFontName, const char *pGothicFontName ) ;
int WINAPI SetTmFontSize ( int nFontSize ) ;
int WINAPI SetUserDefinition ( int nSrcCodePage, int nDstCodePage, int cSrcChar, int cDstChar ) ;
int WINAPI PrintFileStartA ( int nDstCodePage, const char *pDstFileName ) ;
int WINAPI PrintFileStartW ( int nDstCodePage, const wchar_t *pDstFileName ) ;
int WINAPI PrintFileEndA ( int nDstCodePage, const char *pDstFileName ) ;
int WINAPI PrintFileEndW ( int nDstCodePage, const wchar_t *pDstFileName ) ;
int WINAPI GetChnconvLastError ( void ) ;
int WINAPI SetChnconvWindow ( HWND hWnd, int IsDialog ) ;
int WINAPI AbortChnconv ( void ) ;
int WINAPI GetDllVersion ( void ) ;
#ifndef RTFCONV_H
int WINAPI IsAvailableCodePage ( int nSrcCodePage, int nDstCodePage ) ;
#endif


#ifdef UNICODE
#define Chnconv ChnconvW
#define PrintFileStart PrintFileStartW
#define PrintFileEnd PrintFileEndW
#else
#define Chnconv ChnconvA
#define PrintFileStart PrintFileStartA
#define PrintFileEnd PrintFileEndA
#endif



/* Return value of ChnconvEx, GetChnconvLastError */
#define CHNCONV_SUCCESS          0
#define CHNCONV_ERROR_UNKNOWN    1
#define CHNCONV_ERROR_READ       2
#define CHNCONV_ERROR_WRITE      3
#define CHNCONV_ERROR_RTFFORMAT  4
#define CHNCONV_ERROR_RTFBRACE   5
#define CHNCONV_ERROR_MEMORY     6
#define CHNCONV_ERROR_CODEPAGE   7
#define CHNCONV_ERROR_ABORTED    8
#define CHNCONV_ERROR_SEMAPHORE  9
#define CHNCONV_ERROR_PARAM      10


/* for Backward Compatibility */
/* Return value of ChnconvEx, GetChnconvLastError */
#define CHNCONV_ERROR_OVERFLOW   CHNCONV_ERROR_MEMORY



/* for dwConversionMode */
#define CONVMODE_OUTPUT_CODE_NUMBER              1
#define CONVMODE_CHNCONV_NO_GBK                  2
#define CONVMODE_CHNCONV_NO_VARIANT              4
#define CONVMODE_SENSE_CW_FANTIZI                8
#define CONVMODE_QUOTATION_MARK               0x10
#define CONVMODE_INPUT_CODE_NUMBER            0x20
#define CONVMODE_PINYIN_BY_ASCII              0x40
#define CONVMODE_OUTPUT_NEW_FONT              0x80
#define CONVMODE_ONE_QUESTION_MARK           0x100
#define CONVMODE_CW_TXT_FANTIZI              0x800
#define CONVMODE_NO_DECOMPOSE               0x2000
#define CONVMODE_TXT_UNICODE_HTML           0x4000
#define CONVMODE_NO_USE_UNICODE             0x8000
#define CONVMODE_CONVERT_CJKEX             0x10000
#define CONVMODE_LINGSHIDAIMA_TO_CJKEX     0x20000
#define CONVMODE_CJKEX_TO_LINGSHIDAIMA     0x40000
#define CONVMODE_CONVERT_TXT             0x1000000
#define CONVMODE_CONVERT_RTF             0x2000000
#define CONVMODE_PEEKMESSAGE            0x80000000



/* for Backward Compatibility */
/* for dwConversionMode */
#define CONVMODE_TM_NO_OUTPUT_RTFFORM       0x1000
#define CONVMODE_NOT_GBK                CONVMODE_CHNCONV_NO_GBK
#define CONVMODE_NOT_VARIANT            CONVMODE_CHNCONV_NO_VARIANT
#define CONVMODE_NO_MULTI_CHAR          CONVMODE_NO_DECOMPOSE



/* for dwAdditionalMode */
#define ADDITIONAL_MODE_WRITE_TM_COMMENT         1



/* Definitions of Codepage */
#define CP_CHINESE_SIMPLIFIED    936      /* Chinese Simplified (GB2312/GBK) */
#define CP_CHINESE_TRADITIONAL   950      /* Chinese Traditional (BIG5) */
#define CP_CHINESE_CW      ( 932 + 0x10000 )    /* Chinese Writer */
#define CP_CHINESE_NH      ( 932 + 0x20000 )    /* Nihao */
#define CP_CHINESE_CWN     ( 932 + 0x30000 )    /* cWnn */
#define CP_CHINESE_ZQ      ( 932 + 0x40000 )    /* Zhongwen Qigao */
#define CP_CHINESE_CX      ( 932 + 0x50000 )    /* CX */
#define CP_CHINESE_TM      ( 932 + 0x60000 )    /* TechnoMate Zhongguoyu */
#define CP_CHINESE_ZJ      ( 932 + 0x70000 )    /* Zhuojue */
#define CP_CHINESE_FW      ( 932 + 0x80000 )    /* Font Wenhua */
#define CP_HZ_CHINESE_SIMPLIFIED    52936       /* Chinese Simplified (HZ) */



#ifdef __cplusplus
}
#endif

#endif
